@@ -1,6 +1,6 @@
 import math
 
-def binomialcoef(a,b):
+def getbinomialcoef(a,b):
 	if b == 1 or a == b:
 	    return 1
 	if y > x:
